==> haskell-data-array-byte-0.1.0.1-80-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-array-byte.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-array-byte
version:              0.1.0.1
visibility:           public
id:                   data-array-byte-0.1.0.1-6RaQWc9qixK5rBaB40CxXf
key:                  data-array-byte-0.1.0.1-6RaQWc9qixK5rBaB40CxXf
license:              BSD-3-Clause
copyright:            (c) Roman Leshchinskiy 2009-2012
maintainer:           andrew.lelechenko@gmail.com
author:               Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:             https://github.com/Bodigrim/data-array-byte
synopsis:             Compatibility layer for Data.Array.Byte
description:
    Compatibility layer for [Data.Array.Byte](https://hackage.haskell.org/package/base/docs/Data-Array-Byte.html), providing boxed wrappers for @ByteArray#@ and @MutableByteArray#@ and relevant instances for GHC < 9.4. Include it into your Cabal file:

    > build-depends: base
    > if impl(ghc < 9.4)
    >   build-depends: data-array-byte

    and then @import Data.Array.Byte@ unconditionally.

category:             Compatibility
abi:                  416e93b21ecc806ffe1c10fe40e5a6e1
exposed:              True
exposed-modules:      Data.Array.Byte
import-dirs:          /usr/lib/ghc-9.2.8/site-local/data-array-byte-0.1.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/data-array-byte-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-array-byte
hs-libraries:         HSdata-array-byte-0.1.0.1-6RaQWc9qixK5rBaB40CxXf
depends:
    base-4.16.4.0 deepseq-1.4.6.1 template-haskell-2.18.0.0

haddock-interfaces:
    /usr/share/doc/haskell-data-array-byte/html/data-array-byte.haddock

haddock-html:         /usr/share/doc/haskell-data-array-byte/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-array-byte-0.1.0.1-82-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-array-byte.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-array-byte
version:              0.1.0.1
visibility:           public
id:                   data-array-byte-0.1.0.1-3GdB6U3lWZEI2cJx8RfqhQ
key:                  data-array-byte-0.1.0.1-3GdB6U3lWZEI2cJx8RfqhQ
license:              BSD-3-Clause
copyright:            (c) Roman Leshchinskiy 2009-2012
maintainer:           andrew.lelechenko@gmail.com
author:               Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:             https://github.com/Bodigrim/data-array-byte
synopsis:             Compatibility layer for Data.Array.Byte
description:
    Compatibility layer for [Data.Array.Byte](https://hackage.haskell.org/package/base/docs/Data-Array-Byte.html), providing boxed wrappers for @ByteArray#@ and @MutableByteArray#@ and relevant instances for GHC < 9.4. Include it into your Cabal file:

    > build-depends: base
    > if impl(ghc < 9.4)
    >   build-depends: data-array-byte

    and then @import Data.Array.Byte@ unconditionally.

category:             Compatibility
abi:                  b0fbb9ada3f7f7968628bd6c2b30e20d
exposed:              True
exposed-modules:      Data.Array.Byte
import-dirs:          /usr/lib/ghc-9.2.8/site-local/data-array-byte-0.1.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/data-array-byte-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-array-byte
hs-libraries:         HSdata-array-byte-0.1.0.1-3GdB6U3lWZEI2cJx8RfqhQ
depends:
    base-4.16.4.0 deepseq-1.4.6.1 template-haskell-2.18.0.0

haddock-interfaces:
    /usr/share/doc/haskell-data-array-byte/html/data-array-byte.haddock

haddock-html:         /usr/share/doc/haskell-data-array-byte/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
